View source: R/UnivariateObtainQuantileDistribution.R
| getQuantile.test | R Documentation |
Get the quantile theta from several distributions with user defined mean and variance.
getQuantile.test( Ftheta, mu, sigma, dist, par.location = 0, par.scale = 1, par.shape = 1, dist.par = NULL )
Ftheta |
scalar. Quantile of the data distribution. The values that take are between (0,1). |
mu |
scalar. Expected value of the desired distribution. |
sigma |
scalar. Standard deviation of the desired distribution. |
dist |
character string. Select from:
|
par.location |
scalar. Location parameter of the desired distribution. Default 0**. |
par.scale |
scalar. Scale parameter of the desired distribution. Default 1**. |
par.shape |
scalar. Shape parameter of the desired distribution, Default 1. |
dist.par |
vector. Overwrite
|
A quantile theta of the selected Ftheta distribution with its parameters.
getQuantile.test(0.5, 0, 1, "Normal")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.