View source: R/MultivariateObtainAverageRunLength.R
| mgetARL | R Documentation |
Get the ARL getRL.test
mgetARL( n, m, nv, theta = NULL, Ftheta = NULL, dists, dists.par = NULL, mu, sigma = NULL, chart = "T2", chart.par = c(0.005), correlation = 0, s = NULL, replicates = 10000, isParallel = TRUE, print.RL = FALSE, progress = FALSE, calibrate = FALSE, arl0 = 370, alignment = "unadjusted", constant = NULL, absolute = FALSE )
n |
scalar. Subroup size |
m |
scalar. Reference sample size |
nv |
scalar. Number of variables to be generated. |
theta |
vector. Value corresponding with the |
Ftheta |
vector. Quantile of the data distribution. The values that take are between (0,1). |
dists |
vector of character string. Distribution of each variable. The length mus be the same as the number of variables. Select from:
|
dists.par |
matrix For each variable (column), specify
The number of columns must be the same as the number of variables. |
mu |
vector. Two elements of the vector the first one is the mean of the reference sample and the second one is the mean of the monitoring sample. |
sigma |
scalar. Standard deviation of the desired distribution. |
chart |
character string. Selected type of chart. One option available:
|
chart.par |
vector. Control limit and other parameters of the selected chart. |
correlation |
scalar. Corralation between variables. |
s |
matrix. Correlation matrix of the variables |
replicates |
scalar. Number of replicates to get the ARL |
isParallel |
logical. If |
print.RL |
logical. If |
progress |
logical. If |
calibrate |
logical. If |
arl0 |
scalar. Expected value of the RL. It is only used for stop the RL if exceeds 10 times its value. Default |
mgetARL(replicates=50,n=5,m=100,nv=2,mu=c(0,0),
dists = c("Normal", "Normal"), dists.par = matrix(c(0,1,1,0,1,1), ncol=2),
isParallel=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.